@@ -52,7 +52,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 355
+#define gmic_version 362
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -464,7 +464,8 @@ struct gmic {
 
   // Class attributes.
   static const char *builtin_command_names[];
-  static gmic_image<int> builtin_command_inds;
+  static const int builtin_command_ids[];
+  static gmic_image<int> builtin_commands_bounds;
   static gmic_image<char> stdlib;
   static bool is_display_available;
 
